@@ -131,19 +131,23 @@ sudo chgrp -v utmp $R/var/log/lastlog
 sudo chmod -v 664  $R/var/log/lastlog
 sudo chmod -v 600  $R/var/log/btmp
 
-umount -l $R/proc
-rm -rf $R/proc/self
+sudo umount -l $R/proc
+sudo rm -rf $R/proc/self
 
 export INSTALL_ROOT=$R
-yes |  INSTALL_ROOT=$R bulge setup
-yes |  INSTALL_ROOT=$R bulge gi base
-yes |  INSTALL_ROOT=$R bulge i gnutls libxcrypt libgcrypt grub2 btrfs-progs grep
-yes |  INSTALL_ROOT=$R bulge i networkmanager
-yes |  INSTALL_ROOT=$R bulge i bulge
 
-yes |  INSTALL_ROOT=$R bulge i linux-firmware networkmanager vim nano grub2 e2fsprogs grep btrfs-progs gcr mutter sudo
+yes |  sudo env INSTALL_ROOT=$R bulge setup
+yes |  sudo env INSTALL_ROOT=$R bulge gi base
+yes |  sudo env INSTALL_ROOT=$R bulge i gnutls libxcrypt libgcrypt grub2 btrfs-progs grep
+yes |  sudo env INSTALL_ROOT=$R bulge i networkmanager
+yes |  sudo env INSTALL_ROOT=$R bulge i bulge
+
+yes |  sudo env INSTALL_ROOT=$R bulge i linux-firmware vim nano e2fsprogs gcr sudo xf86-input-libinput make-ca accountsservice
+
+yes |  sudo env INSTALL_ROOT=$R bulge gi gnome
+
+yes |  sudo env INSTALL_ROOT=$R bulge i gnome-backgrounds
 
-yes |  INSTALL_ROOT=$R bulge gi gnome
 
 sudo mount -vt tmpfs tmpfs $R/run
 sudo ln -s /run $R/var/run
@@ -161,7 +165,7 @@ case $(uname -m) in
     ;;
 esac
 
-sudo genfstab -U $R > $R/etc/fstab
+sudo genfstab -U $R | sudo tee $R/etc/fstab
 
 echo '#!/bin/bash' | sudo tee -a $R/root/yiffosP2
 echo 'ln -s /usr/bin/bash /usr/bin/sh' | sudo tee -a $R/root/yiffosP2
@@ -174,13 +178,14 @@ echo "dracut --kver ${KVER}yiffOS --force" | sudo tee -a $R/root/yiffosP2
 echo 'grub-mkconfig -o /boot/grub/grub.cfg' | sudo tee -a $R/root/yiffosP2
 echo 'pwconv' | sudo tee -a $R/root/yiffosP2
 echo 'grpconv' | sudo tee -a $R/root/yiffosP2
-chmod +x $R/root/yiffosP2
+
+sudo chmod +x $R/root/yiffosP2
 
 sudo chroot "/mnt/root" /usr/bin/env -i	\
 	HOME=/root                  	\
 	TERM="$TERM"                	\
 	PS1='(yiffOS chroot) \u:\w\$ ' 	\
 	PATH=/usr/bin:/usr/sbin     	\
-	/bin/bash /root/yiffosP2
+	/root/yiffosP2
 
 exit 0
